@@ -17,8 +17,8 @@ import logging
 from django.contrib import messages
 from django.core.paginator import EmptyPage
 from django.core.paginator import Paginator
-from django.core.urlresolvers import reverse
-from django.core.urlresolvers import reverse_lazy
+from django.urls import reverse
+from django.urls import reverse_lazy
 from django.utils.translation import ugettext as _  # noqa
 from django.views.generic import TemplateView
 import six
